@@ -8,7 +8,7 @@
  *                                                                                      *
  * This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
  * WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
- * PARTICULAR PURPOSE. See the GNU General Pulic License for more details.              *
+ * PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
  *                                                                                      *
  * You should have received a copy of the GNU General Public License along with         *
  * this program.  If not, see <http://www.gnu.org/licenses/>.                           *
@@ -37,7 +37,7 @@ class QPalette;
 class BlockAnalyzer : public Analyzer::Base2D
 {
 public:
-    BlockAnalyzer( QWidget* );
+    explicit BlockAnalyzer( QWidget* );
     ~BlockAnalyzer();
 
     // Signed ints because most of what we compare them against are ints
